CommentController class

Inheritance

Constructors

CommentController()

Properties

canAddImage ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
listOfComments ↔ List<CommentDTO>
getter/setter pairinherited
listOfImage ↔ List<Media>
getter/setter pairinherited
mainBoxFontSize ↔ double
getter/setter pairinherited
mainBoxshowBoxShadow ↔ bool
getter/setter pairinherited
mainCommentBoxColor ↔ Color
getter/setter pairoverride
mainCommnetId ↔ int
getter/setter pairinherited
mainUserNameFontSize ↔ double
getter/setter pairinherited
mainUserNameFontWeight ↔ FontWeight
getter/setter pairinherited
replyTo ↔ String?
getter/setter pairinherited
replyYes ↔ bool
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBoxShadow ↔ bool
getter/setter pair
subBoxFontSize ↔ double
getter/setter pairinherited
subBoxshowBoxShadow ↔ bool
getter/setter pairinherited
subCommentBoxColor ↔ Color
getter/setter pairinherited
subCommentId ↔ int
getter/setter pairinherited
subCommentUserNameFontSize ↔ double
getter/setter pairinherited
subCommnetReplyYes ↔ bool
getter/setter pairinherited
subUserNameFontWeight ↔ FontWeight
getter/setter pairinherited
tagToFontSize ↔ double
getter/setter pairinherited
tagToWeight ↔ FontWeight
getter/setter pairinherited
textController → TextEditingController
finalinherited

Methods

addMainComment({required String comment, String? postId}) → dynamic
inherited
addSubComment({required String comment, required int mainCommentId, String? postId}) → dynamic
inherited
changCommentState() → dynamic
inherited
clearAllComment() → dynamic
inherited
deleteComment({required CommentDTO dto, required int mainCommentId, String? postId, dynamic String}) → dynamic
inherited
deleteSubComment({required SubCommentDTO dto, required int mainCommentId, String? postId}) → dynamic
inherited
editComment({required CommentDTO dto, required int index, String? postId}) → dynamic
inherited
editSubComment({required SubCommentDTO dto, required int mainCommentId, required int subCommentId, String? postId}) → dynamic
inherited
getEmojiesForLike() → List<CommentLike>
inherited
getImageUril(int index, List<Media> list) → String
inherited
getMainCommentTime(int mainComentIndex) → String
inherited
getSubCommentTime(int mainComentIndex, int subCommentId) → String
inherited
imageComment({String? postId, required String userId, required List<Media> list}) → dynamic
inherited
likeForMainComment({required int likeTypeId, required String likeType, required int mainCommentId, String? postId, required String userId}) → dynamic
inherited
likeForSubComment({required int likeTypeId, required String likeType, required int mainCommentId, required int subCommentID, String? postId, required String userId}) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replyCancel() → dynamic
inherited
replyToSubCommnet({required String comment, required int mainCommentId, required dynamic subCommentId, String? postId}) → dynamic
inherited
toString() → String
A string representation of this object.
inherited
updateComment({required CommentDTO dto, required int index, String? postId}) → dynamic
inherited
updateSubComment({required SubCommentDTO dto, required int mainCommentId, required int subCommentId}) → dynamic
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited