ManageComment class

Implementers

Constructors

ManageComment()

Properties

canAddImage ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listOfComments ↔ List<CommentDTO>
getter/setter pair
listOfImage ↔ List<Media>
getter/setter pair
mainBoxFontSize ↔ double
getter/setter pair
mainBoxshowBoxShadow ↔ bool
getter/setter pair
mainCommentBoxColor ↔ Color
getter/setter pair
mainCommnetId ↔ int
getter/setter pair
mainUserNameFontSize ↔ double
getter/setter pair
mainUserNameFontWeight ↔ FontWeight
getter/setter pair
replyTo ↔ String?
getter/setter pair
replyYes ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subBoxFontSize ↔ double
getter/setter pair
subBoxshowBoxShadow ↔ bool
getter/setter pair
subCommentBoxColor ↔ Color
getter/setter pair
subCommentId ↔ int
getter/setter pair
subCommentUserNameFontSize ↔ double
getter/setter pair
subCommnetReplyYes ↔ bool
getter/setter pair
subUserNameFontWeight ↔ FontWeight
getter/setter pair
tagToFontSize ↔ double
getter/setter pair
tagToWeight ↔ FontWeight
getter/setter pair
textController → TextEditingController
final

Methods

addMainComment({required String comment, String? postId}) → dynamic
addSubComment({required String comment, required int mainCommentId, String? postId}) → dynamic
changCommentState() → dynamic
clearAllComment() → dynamic
deleteComment({required CommentDTO dto, required int mainCommentId, String? postId, dynamic String}) → dynamic
deleteSubComment({required SubCommentDTO dto, required int mainCommentId, String? postId}) → dynamic
editComment({required CommentDTO dto, required int index, String? postId}) → dynamic
editSubComment({required SubCommentDTO dto, required int mainCommentId, required int subCommentId, String? postId}) → dynamic
getEmojiesForLike() → List<CommentLike>
getImageUril(int index, List<Media> list) → String
getMainCommentTime(int mainComentIndex) → String
getSubCommentTime(int mainComentIndex, int subCommentId) → String
imageComment({String? postId, required String userId, required List<Media> list}) → dynamic
likeForMainComment({required int likeTypeId, required String likeType, required int mainCommentId, String? postId, required String userId}) → dynamic
likeForSubComment({required int likeTypeId, required String likeType, required int mainCommentId, required int subCommentID, String? postId, required String userId}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replyCancel() → dynamic
replyToSubCommnet({required String comment, required int mainCommentId, required dynamic subCommentId, String? postId}) → dynamic
toString() → String
A string representation of this object.
inherited
updateComment({required CommentDTO dto, required int index, String? postId}) → dynamic
updateSubComment({required SubCommentDTO dto, required int mainCommentId, required int subCommentId}) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited