SubCommentDTO class

Constructors

SubCommentDTO({String? id, required String postId, required String commentedBy, required String userId, required String userDispalyName, String? userImgUrl = "", String? tagTo, required DateTime commentedDate, required String comment, required List<String> commentImgUrl, required List<CommentLike> commentLikeCounts, required List<LikedUser> likesUsers})

Properties

comment ↔ String
getter/setter pair
commentedBy ↔ String
getter/setter pair
commentedDate ↔ DateTime
getter/setter pair
commentImgUrl ↔ List<String>
getter/setter pair
commentLikeCounts ↔ List<CommentLike>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
likesUsers ↔ List<LikedUser>
getter/setter pair
postId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagTo ↔ String?
getter/setter pair
userDispalyName ↔ String
getter/setter pair
userId ↔ String
getter/setter pair
userImgUrl ↔ String?
getter/setter pair

Methods

getLikeCount() → dynamic
getMainCommentTime() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited